PyBaccarat: tests.test_ties Namespace Reference

PyBaccarat visit the ministry of silly walks

Classes | Variables
tests.test_ties Namespace Reference

Unit test for the Ties class. More...

## Classes
class | TestTies

## Variables
| HERE = os.path.dirname(os.path.abspath(__file__))

## Detailed Description

Unit test for the Ties class.

To execute the unit test from base dir location, enter:

cd pybaccarat_base
python tests\unittest_ties.py [-v]
rem Run a single test case
cd C:\git\PyBaccarat
python tests\unittest_ties.py TestTies.test_basic

Author
  fulkg.nosp@m.l@gm.nosp@m.ail.c.nosp@m.om